==> 1.0.1.tar.gz: lib/src/mockup_splash_screen.dart <==
// ignore_for_file: prefer_const_literals_to_create_immutables
import 'package:dotup_flutter_widgets/dotup_flutter_widgets.dart';
import 'package:flutter/material.dart';

const TOB_COLOR = Color.fromARGB(255, 0x26, 0x27, 0x4f);

class MockupSplashScreen extends StatelessWidget {
  const MockupSplashScreen({
    Key? key,
    this.onTap,
  }) : super(key: key);

  final VoidCallback? onTap;

  @override
  Widget build(BuildContext context) {
    // Future.delayed(const Duration(seconds: 1)).then((value) {
    //   Navigator.of(context).restorablePushReplacementNamed(OperationListView.routeName);
    // });
    return Material(
      child: InkWell(
        onTap: onTap,
        child: Container(
          color: TOB_COLOR,
          child: Column(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Column(
                crossAxisAlignment: CrossAxisAlignment.stretch,
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  const SizedBox(height: 60),
                  const Center(child: Text('dotup IT solutions')),
                  const SizedBox(height: 30),
                  Center(
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: [
                        const Text(
                          'Mockup Presenter v1.0.0',
                          style: TextStyle(fontSize: 16),
                        ),
                        const Padding(
                          padding: EdgeInsets.only(left: 4),
                          child: Icon(Icons.dashboard),
                        ),
                      ],
                    ),
                  ),
                  const SizedBox(height: 30),
                  SizedBox(height: 60, width: 60, child: DotupLogo(size: 60)),
                ],
              ),
              Padding(
                padding: EdgeInsets.all(16),
                child: TextButton(onPressed: onTap, child: Text('weiter')),
              )
            ],
          ),
        ),
      ),
    );
  }
}
  
  //   return FutureBuilder(
  //     future: Future.delayed(const Duration(seconds: 3)),
  //     builder: (context, snapshot) {
  //       if (snapshot.connectionState == ConnectionState.done) {
  //         Navigator.of(context).restorablePushReplacementNamed(OperationListView.routeName);
  //         return SizedBox.shrink();
  //       } else {
  //         return Material(
  //           child: Container(
  //             color: const Color.fromARGB(255, 0x26, 0x27, 0x4f),
  //             child: Center(
  //               child: Text('tobaccoland'),
  //             ),
  //           ),
  //         );
  //       }
  //     },
  //   );
  // }
// }

==> 1.1.1.tar.gz: lib/src/mockup_splash_screen.dart <==
// ignore_for_file: prefer_const_literals_to_create_immutables
import 'package:dotup_flutter_widgets/dotup_flutter_widgets.dart';
import 'package:flutter/material.dart';

const TOB_COLOR = Color.fromARGB(255, 0x26, 0x27, 0x4f);

class MockupSplashScreen extends StatefulWidget {
  MockupSplashScreen({
    Key? key,
    required this.onTap,
  }) : super(key: key);

  final ValueSetter<bool> onTap;

  @override
  State<MockupSplashScreen> createState() => _MockupSplashScreenState();
}

class _MockupSplashScreenState extends State<MockupSplashScreen> {
  bool _showPageInfos = true;

  @override
  Widget build(BuildContext context) {
    // Future.delayed(const Duration(seconds: 1)).then((value) {
    //   Navigator.of(context).restorablePushReplacementNamed(OperationListView.routeName);
    // });
    return Material(
      child: InkWell(
        onTap: () => widget.onTap(_showPageInfos),
        child: Container(
          color: TOB_COLOR,
          child: Column(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Column(
                crossAxisAlignment: CrossAxisAlignment.stretch,
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  const SizedBox(height: 60),
                  const Center(child: Text('dotup IT solutions')),
                  const SizedBox(height: 30),
                  Center(
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: [
                        const Text(
                          'Mockup Presenter v1.0.0',
                          style: TextStyle(fontSize: 16),
                        ),
                        const Padding(
                          padding: EdgeInsets.only(left: 4),
                          child: Icon(Icons.dashboard),
                        ),
                      ],
                    ),
                  ),
                  const SizedBox(height: 30),
                  SizedBox(height: 60, width: 60, child: DotupLogo(size: 60)),
                ],
              ),
              Padding(
                padding: EdgeInsets.all(16),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.stretch,
                  children: [
                    CheckboxListTile(
                        title: const Text('Seitenfinfos anzeigen'),
                        value: _showPageInfos,
                        onChanged: (value) {
                          setState(() {
                            _showPageInfos = value ?? true;
                          });
                        }),
                    TextButton(
                        onPressed: () => widget.onTap(_showPageInfos),
                        child: const Padding(
                          padding: EdgeInsets.all(16.0),
                          child: Text('weiter'),
                        )),
                  ],
                ),
              )
            ],
          ),
        ),
      ),
    );
  }
}
  
  //   return FutureBuilder(
  //     future: Future.delayed(const Duration(seconds: 3)),
  //     builder: (context, snapshot) {
  //       if (snapshot.connectionState == ConnectionState.done) {
  //         Navigator.of(context).restorablePushReplacementNamed(OperationListView.routeName);
  //         return SizedBox.shrink();
  //       } else {
  //         return Material(
  //           child: Container(
  //             color: const Color.fromARGB(255, 0x26, 0x27, 0x4f),
  //             child: Center(
  //               child: Text('tobaccoland'),
  //             ),
  //           ),
  //         );
  //       }
  //     },
  //   );
  // }
// }
